@@ -46,23 +46,23 @@ impliedcovstructures <- function(
       # Only need to do things if all = TRUE:
       if (all){
         if (!all(x[[g]][[sigma]] == 0)){
-          x[[g]][[kappa]] <- as(solve_symmetric(x[[g]][[sigma]]), "Matrix")
-          x[[g]][[omega]]  <- as(qgraph::wi2net(as.matrix(x[[g]][[kappa]])),"Matrix")
-          x[[g]][[rho]] <- as(cov2cor(as.matrix(x[[g]][[sigma]])),"Matrix")
-          x[[g]][[SD]] <- as(diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))),"Matrix")
+          x[[g]][[kappa]] <- as.matrix(solve_symmetric(x[[g]][[sigma]]))
+          x[[g]][[omega]]  <- as.matrix(qgraph::wi2net(as.matrix(x[[g]][[kappa]])))
+          x[[g]][[rho]] <- as.matrix(cov2cor(as.matrix(x[[g]][[sigma]])))
+          x[[g]][[SD]] <- Diagonal(x=diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))))
         }
       }
     } else if(type == "chol"){
       # form cov matrix:
-      x[[g]][[sigma]] <- as(x[[g]][[lowertri]] %*% t(x[[g]][[lowertri]]), "Matrix")
+      x[[g]][[sigma]] <- as.matrix(x[[g]][[lowertri]] %*% t(x[[g]][[lowertri]]))
       
       # Return precision and network if all = TRUE:
       if (all){
         if (!all(x[[g]][[sigma]] == 0)){
-          x[[g]][[kappa]] <- as(solve_symmetric(x[[g]][[sigma]]), "Matrix")
-          x[[g]][[omega]]  <- as(qgraph::wi2net(as.matrix(x[[g]][[kappa]])),"Matrix")
-          x[[g]][[rho]] <- as(cov2cor(as.matrix(x[[g]][[sigma]])),"Matrix")
-          x[[g]][[SD]] <- as(diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))),"Matrix")
+          x[[g]][[kappa]] <- as.matrix(solve_symmetric(x[[g]][[sigma]]))
+          x[[g]][[omega]]  <- as.matrix(qgraph::wi2net(as.matrix(x[[g]][[kappa]])))
+          x[[g]][[rho]] <- as.matrix(cov2cor(as.matrix(x[[g]][[sigma]])))
+          x[[g]][[SD]] <- Diagonal(x=diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))))
         }
 
       }
@@ -70,22 +70,21 @@ impliedcovstructures <- function(
       # First check if the delta Matrix is present (it is ignored when corinput = TRUE only, so don't need to know that that argument was used):
       if (is.null(x[[g]][[delta]])){
         # FIXME: non positive definite matrices are even worse here... So I am trying to solve this with a spectral shift for now:
-        IminO_dummy <-  as(solve_symmetric(spectralshift(Diagonal(ncol(x[[g]][[omega]])) - x[[g]][[omega]])), "Matrix")
+        IminO_dummy <-  as.matrix(solve_symmetric(spectralshift(Diagonal(ncol(x[[g]][[omega]])) - x[[g]][[omega]])))
         x[[g]][[delta]] <- Diagonal(x = diag(IminO_dummy)^(-0.5))
       } else {
-        IminO_dummy <-  as(solve_symmetric(Diagonal(ncol(x[[g]][[omega]])) - x[[g]][[omega]]), "Matrix")
+        IminO_dummy <-  as.matrix(solve_symmetric(Diagonal(ncol(x[[g]][[omega]])) - x[[g]][[omega]]))
         
       }
       
-      
-      x[[g]][[sigma]] <- x[[g]][[delta]] %*%IminO_dummy  %*% x[[g]][[delta]]
+      x[[g]][[sigma]] <- as.matrix(x[[g]][[delta]] %*%IminO_dummy  %*% x[[g]][[delta]])
       
       # Stuff needed if all = TRUE:
       if (all){
         if (!all(x[[g]][[sigma]] == 0)){
-          x[[g]][[kappa]] <- solve_symmetric(x[[g]][[sigma]])
-          x[[g]][[rho]] <- as(cov2cor(as.matrix(x[[g]][[sigma]])),"Matrix")
-          x[[g]][[SD]] <- as(diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))),"Matrix")
+          x[[g]][[kappa]] <- as.matrix(solve_symmetric(x[[g]][[sigma]]))
+          x[[g]][[rho]] <- as.matrix(cov2cor(as.matrix(x[[g]][[sigma]])))
+          x[[g]][[SD]] <- Diagonal(x=diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))))
         }
         
       }
@@ -93,16 +92,16 @@ impliedcovstructures <- function(
       # Extra matrix needed:
       if (!all){
         x[[g]][[IminOinv]] <- IminO_dummy
-        x[[g]][[delta_IminOinv]] <- x[[g]][[delta]] %*% x[[g]][[IminOinv]]
+        x[[g]][[delta_IminOinv]] <- as.matrix(x[[g]][[delta]] %*% x[[g]][[IminOinv]])
       }
     } else if (type == "prec"){
       # Precision matrix
-      x[[g]][[sigma]] <- as(solve_symmetric(x[[g]][[kappa]]),"Matrix")
+      x[[g]][[sigma]] <- as.matrix(solve_symmetric(x[[g]][[kappa]]))
       
       if (all) {
-        x[[g]][[omega]] <- as(qgraph::wi2net(as.matrix(x[[g]][[kappa]])),"Matrix")
-        x[[g]][[rho]] <- as(cov2cor(as.matrix(x[[g]][[sigma]])),"Matrix")
-        x[[g]][[SD]] <- as(diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))),"Matrix")
+        x[[g]][[omega]] <- as.matrix(qgraph::wi2net(as.matrix(x[[g]][[kappa]])))
+        x[[g]][[rho]] <- as.matrix(cov2cor(as.matrix(x[[g]][[sigma]])))
+        x[[g]][[SD]] <- Diagonal(x=diag(sqrt(diag(as.matrix(x[[g]][[sigma]])))))
       }
     } else if (type == "cor"){
 
@@ -111,21 +110,21 @@ impliedcovstructures <- function(
         x[[g]][[SD]] <- Diagonal(ncol(x[[g]][[rho]]))
       }
       
-      x[[g]][[sigma]] <- x[[g]][[SD]] %*% (Diagonal(ncol(x[[g]][[rho]])) + x[[g]][[rho]]) %*% x[[g]][[SD]]
+      x[[g]][[sigma]] <- as.matrix(x[[g]][[SD]] %*% (Diagonal(ncol(x[[g]][[rho]])) + x[[g]][[rho]]) %*% x[[g]][[SD]])
       
       # Stuff needed if all = TRUE:
       if (all){
         if (!all(x[[g]][[sigma]] == 0)){
-          x[[g]][[kappa]] <- solve_symmetric(x[[g]][[sigma]])
-          x[[g]][[omega]]  <- as(qgraph::wi2net(as.matrix(x[[g]][[kappa]])),"Matrix")
+          x[[g]][[kappa]] <- as.matrix(solve_symmetric(x[[g]][[sigma]]))
+          x[[g]][[omega]]  <- as.matrix(qgraph::wi2net(as.matrix(x[[g]][[kappa]])))
         }
         
       }
       
       # Extra matrix needed:
       if (!all){
-        x[[g]][[IplusRho]] <- as(Diagonal(ncol(x[[g]][[rho]])) + x[[g]][[rho]], "Matrix")
-        x[[g]][[SD_IplusRho]] <- x[[g]][[SD]] %*% x[[g]][[IplusRho]]
+        x[[g]][[IplusRho]] <- as.matrix(Diagonal(ncol(x[[g]][[rho]])) + x[[g]][[rho]])
+        x[[g]][[SD_IplusRho]] <- as.matrix(x[[g]][[SD]] %*% x[[g]][[IplusRho]])
       }
       
       
