@@ -36,6 +36,8 @@ prepare_meta_varcov <- function(x, model){
     groupModels[[g]]$means <- means[[g]]
     groupModels[[g]]$corinput <- FALSE
     groupModels[[g]]$metacor <-  model@sample@corinput
+    groupModels[[g]]$cpp <- model@cpp
+    groupModels[[g]]$meanstructure <- model@meanstructure
   }
 
   # Return
