@@ -14,16 +14,16 @@ using namespace arma;
 arma::vec psychonetrics_gradient_cpp(
     arma::vec x,
     const S4& model,
-    bool useM = false,
-    bool sparsemodel = false
+    bool sparsemodel = false,
+    bool useM = false
 );
 
 void psychonetrics_gradient_cpp_inner(
     const arma::vec& x,
     arma::vec& grad,
     const S4& model,
-    bool useM = false,
-    bool sparsemodel = false
+    bool sparsemodel = false,
+    bool useM = false
 );
 
 #endif
